@@ -1,4 +1,8 @@
-__all__ = ['term', 'logfile', 'github_auth_device', 'limit_cb', 'api', 'Events', 'print_event', 'tail_events', 'watch_users', 'quad_logs', 'simple', 'main']
+
+
+__all__ = ['term', 'logfile', 'github_auth_device', 'limit_cb', 'api', 'Events', 'print_event', 'tail_events',
+           'watch_users', 'quad_logs', 'simple', 'main']
+
 
 import time, sys, signal, shutil, os, json, enlighten, emoji, blessed
 from dashing import *
@@ -11,9 +15,11 @@ from fastcore.foundation import *
 from fastcore.script import *
 from ghapi.all import *
 
+
 term = Terminal()
 logfile = Path("log.txt")
 
+
 def github_auth_device(wb='', n_polls=9999):
     "Authenticate with GitHub, polling up to `n_polls` times to wait for completion"
     auth = GhDeviceAuth()
@@ -28,15 +34,18 @@ def github_auth_device(wb='', n_polls=9999):
     print("Authenticated with GitHub")
     return token
 
+
 def _exit(msg):
     print(msg, file=sys.stderr)
     sys.exit()
 
+
 def limit_cb(rem,quota):
     "Callback to warn user when close to using up hourly quota"
     w='WARNING '*7
     if rem < 1000: print(f"{w}\nRemaining calls: {rem} out of {quota}\n{w}", file=sys.stderr)
 
+
 def _get_api():
     path = Path.home()/".ghtop_token"
     if path.is_file():
@@ -48,6 +57,7 @@ def _get_api():
 
 api = _get_api()
 
+
 Events = dict(
     IssuesEvent_closed=('⭐', 'closed', noop),
     IssuesEvent_opened=('📫', 'opened', noop),
@@ -56,6 +66,7 @@ Events = dict(
     PullRequestEvent_closed=('✔', 'closed a pull request', term.green),
 )
 
+
 def _to_log(e):
     login,repo,pay = e.actor.login,e.repo.name,e.payload
     typ = e.type + (f'_{pay.action}' if e.type in ('PullRequestEvent','IssuesEvent') else '')
@@ -66,17 +77,20 @@ def _to_log(e):
         return color(f'{emoji} {login} {msg}{xtra} on repo {repo[:20]} ("{d.title[:50]}...")')
     elif e.type == "ReleaseEvent": return f'🚀 {login} released {e.payload.release.tag_name} of {repo}'
 
+
 def print_event(e, commits_counter):
     res = _to_log(e)
     if res: print(res)
     elif e.type == "PushEvent": [commits_counter.update() for c in e.payload.commits]
     elif e.type == "SecurityAdvisoryEvent": print(term.blink("SECURITY ADVISORY"))
 
-def tail_events():
+
+def tail_events(evt):
     "Print events from `fetch_events` along with a counter of push events"
     manager = enlighten.get_manager()
     commits = manager.counter(desc='Commits', unit='commits', color='green')
-    for ev in fetch_events(): print_event(ev, commits)
+    for ev in evt: print_event(ev, commits)
+
 
 def _pr_row(*its): print(f"{its[0]: <30} {its[1]: <6} {its[2]: <5} {its[3]: <6} {its[4]: <7}")
 def watch_users(evts):
@@ -93,6 +107,7 @@ def watch_users(evts):
         for u in sorted_users[:20]:
             _pr_row(*u, *itemgetter('PullRequestEvent','IssuesEvent','PushEvent')(users_events[u[0]]))
 
+
 def _push_to_log(e): return f"{e.actor.login} pushed {len(e.payload.commits)} commits to repo {e.repo.name}"
 def _logwin(title,color): return Log(title=title,border_color=2,color=color)
 
@@ -112,9 +127,11 @@ def quad_logs(evts):
             if x.type in d: d[x.type].append(f(x)[:95])
         ui.display()
 
+
 def simple(evts):
     for ev in evts: print(f"{ev.actor.login} {ev.type} {ev.repo.name}")
 
+
 def _signal_handler(sig, frame):
     if sig != signal.SIGINT: return
     print(term.exit_fullscreen(),term.clear(),term.normal)
@@ -136,4 +153,4 @@ def main(mode:         Param("Operation mode to run", _OpModes),
     if filtval and not filt: _exit("Must pass `filter_type` if passing `filter_value`")
     kwargs = {filt:filtval} if filt else {}
     evts = api.fetch_events(types=types, incl_bot=include_bots, **kwargs)
-    _funcs[mode](evts)
+    _funcs[mode](evts)
\ No newline at end of file
